@@ -6,7 +6,6 @@ use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 use std::str::FromStr;
 
-use assert_cmd::cargo::CommandCargoExt;
 use inferno::flamegraph::color::{BackgroundColor, PaletteMap};
 use inferno::flamegraph::{self, Direction, Options, Palette, TextTruncateDirection};
 use log::Level;
@@ -17,7 +16,7 @@ fn test_flamegraph(
     input_file: &str,
     expected_result_file: &str,
     options: Options<'_>,
-) -> quick_xml::Result<()> {
+) -> io::Result<()> {
     test_flamegraph_multiple_files(
         vec![PathBuf::from_str(input_file).unwrap()],
         expected_result_file,
@@ -29,7 +28,7 @@ fn test_flamegraph_multiple_files(
     input_files: Vec<PathBuf>,
     expected_result_file: &str,
     mut options: Options<'_>,
-) -> quick_xml::Result<()> {
+) -> io::Result<()> {
     // Always pretty print XML to make it easier to find differences when tests fail.
     options.pretty_xml = true;
     // Never include static JavaScript in tests so we don't have to have it duplicated
@@ -45,7 +44,7 @@ fn test_flamegraph_multiple_files(
                 flamegraph::from_files(&mut options, &input_files, &mut f)?;
                 fs::metadata(expected_result_file).unwrap()
             } else {
-                return Err(e.into());
+                return Err(e);
             }
         }
     };
@@ -806,6 +805,18 @@ fn flamegraph_reversed_stack_ordering_with_fractional_samples() {
     test_flamegraph(input_file, expected_result_file, options).unwrap();
 }
 
+#[test]
+fn flamegraph_reversed_stack_ordering_with_space() {
+    let input_file = "./tests/data/flamegraph/fractional-samples/with-space.txt";
+    let expected_result_file = "./tests/data/flamegraph/fractional-samples/with-space-reversed.svg";
+
+    let mut options = flamegraph::Options::default();
+    options.hash = true;
+    options.reverse_stack_order = true;
+
+    test_flamegraph(input_file, expected_result_file, options).unwrap();
+}
+
 #[test]
 fn flamegraph_should_warn_about_no_sort_when_reversing_stack_ordering() {
     let mut options = flamegraph::Options::default();
@@ -861,8 +872,7 @@ fn flamegraph_cli() {
     let expected_file =
         "./tests/data/flamegraph/perf-vertx-stacks/perf-vertx-stacks-01-collapsed-all.svg";
     // Test with file passed in
-    let output = Command::cargo_bin("inferno-flamegraph")
-        .unwrap()
+    let output = Command::new(assert_cmd::cargo::cargo_bin!("inferno-flamegraph"))
         .arg("--pretty-xml")
         .arg("--no-javascript")
         .arg("--hash")
@@ -873,8 +883,7 @@ fn flamegraph_cli() {
     compare_results(Cursor::new(output.stdout), expected, expected_file);
 
     // Test with STDIN
-    let mut child = Command::cargo_bin("inferno-flamegraph")
-        .unwrap()
+    let mut child = Command::new(assert_cmd::cargo::cargo_bin!("inferno-flamegraph"))
         .arg("--pretty-xml")
         .arg("--no-javascript")
         .arg("--hash")
@@ -894,8 +903,7 @@ fn flamegraph_cli() {
         "./tests/data/flamegraph/multiple-inputs/perf-vertx-stacks-01-collapsed-all-unsorted-1.txt";
     let input_file_part2 =
         "./tests/data/flamegraph/multiple-inputs/perf-vertx-stacks-01-collapsed-all-unsorted-2.txt";
-    let output = Command::cargo_bin("inferno-flamegraph")
-        .unwrap()
+    let output = Command::new(assert_cmd::cargo::cargo_bin!("inferno-flamegraph"))
         .arg("--pretty-xml")
         .arg("--no-javascript")
         .arg("--hash")
